==> more_widgets-2.0.7.tar.gz: lib/more_widgets.dart <==
library more_widgets;

import 'package:flutter/material.dart';
import 'package:more_widgets/widgets/overlays/animated_icon_overlay.dart';
import 'package:more_widgets/widgets/overlays/animated_validate_overlay.dart';

void showValidateOverlay({
  required BuildContext context,
  circleSize = 100,
  backgroundColor = Colors.orange,
  iconSize = 80,
  dismissOverlayAutomaticallyAfterAnimation = true,
  animationDurationInSeconds = 2,
}) {
  showDialog(
      context: context,
      builder: (context) {
        return AnimatedValidateOverlay(
          animationDurationInSeconds: animationDurationInSeconds,
          backgroundColor: backgroundColor,
          circleSize: circleSize,
          dismissOverlayAutomaticallyAfterAnimation: dismissOverlayAutomaticallyAfterAnimation,
          iconSize: iconSize,
        );
      }
  );
}

void showIconOverlay({
  required BuildContext context,
  width = 100,
  height = 100,
  backgroundColor = Colors.orange,
  iconSize = 80,
  required icon,
  animationType = AnimationType.rotate,
  dismissOverlayAutomaticallyAfterAnimation = true,
  animationDuration = const Duration(seconds: 2),
}) {
  showDialog(
      context: context,
      builder: (context) {
        return AnimatedIconOverlay(
          icon: icon,
          iconSize: iconSize,
          dismissOverlayAutomaticallyAfterAnimation: dismissOverlayAutomaticallyAfterAnimation,
          backgroundColor: backgroundColor,
          height: height,
          width: width,
          animationDuration: animationDuration,
          animationType: animationType,
        );
      }
  );
}

==> more_widgets-2.0.14.tar.gz: lib/more_widgets.dart <==
library more_widgets;

import 'package:flutter/material.dart';
import 'package:more_widgets/widgets/overlays/animated_icon_overlay.dart';
import 'package:more_widgets/widgets/overlays/animated_validate_overlay.dart';

void showValidateOverlay({
  required BuildContext context,
  double circleSize = 100,
  Color backgroundColor = Colors.orange,
  double iconSize = 80,
  bool dismissOverlayAutomaticallyAfterAnimation = true,
  int animationDurationInSeconds = 2,
}) {
  showDialog(
      context: context,
      builder: (context) {
        return AnimatedValidateOverlay(
          animationDurationInSeconds: animationDurationInSeconds,
          backgroundColor: backgroundColor,
          circleSize: circleSize,
          dismissOverlayAutomaticallyAfterAnimation: dismissOverlayAutomaticallyAfterAnimation,
          iconSize: iconSize,
        );
      }
  );
}

void showIconOverlay({
  required BuildContext context,
  double width = 100,
  double height = 100,
  Color backgroundColor = Colors.orange,
  double iconSize = 80,
  required IconData icon,
  AnimationType animationType = AnimationType.rotate,
  bool dismissOverlayAutomaticallyAfterAnimation = true,
  Duration animationDuration = const Duration(seconds: 2),
}) {
  showDialog(
      context: context,
      builder: (context) {
        return AnimatedIconOverlay(
          icon: icon,
          iconSize: iconSize,
          dismissOverlayAutomaticallyAfterAnimation: dismissOverlayAutomaticallyAfterAnimation,
          backgroundColor: backgroundColor,
          height: height,
          width: width,
          animationDuration: animationDuration,
          animationType: animationType,
        );
      }
  );
}
